#!/usr/bin/env python3
import os
import subprocess

"""
SpaceView
Copyright (C) 2016  Jacob Vlijm
contact: vlijm@planet.nl
This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or any later version. This
program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details. You
should have received a copy of the GNU General Public License along with this
program.  If not, see <http://www.gnu.org/licenses/>.
"""

home = os.environ["HOME"]
prefsdir = os.path.join(home, ".spaceview")

if not os.path.exists(prefsdir):
    os.makedirs(prefsdir)

def read_settings():
    settings = {}
    aliases = get_settings("aliases")
    settings["aliases"] = ev_aliases(aliases) if aliases else []
    color = get_settings("curr_theme")
    settings["color"] = color if color else "orange"
    threshold = get_settings("threshold")
    settings["threshold"] = int(threshold) if threshold else 10
    showconnected = get_settings("showconnected")
    settings["showconnected"] = True if showconnected == "True" else False
    runonstartup = get_settings("runonstartup")
    settings["runonstartup"] = True if runonstartup == "True" else False
    return settings

def get_settings(file):
    try:
        return open(os.path.join(prefsdir, file)).read().strip()
    except FileNotFoundError:
        pass

def ev_aliases(aliases):
    return [l.split("||") for l in aliases.splitlines() if not l == "\n"]

def read_devices(aliases):
    # read the devices, look up their alias and the free sapace
    devdata = []
    data = subprocess.check_output(["df", "-h"]).decode("utf-8").splitlines()
    relevant = [l for l in data if all(
        [any([l.startswith("/dev/"), l.startswith("//")]), not "/loop" in l]
        )]
    for dev in relevant:
        data = dev.split(); name = data[0]; pseudo = None       
        free = 100-int([s.strip("%") for s in data if "%" in s][0])
        for al in aliases:
            if al[0] in name:
                pseudo = al[1]
                break
        devdata.append((name, pseudo, free))
    return devdata


